==> qddb-1.42.2.tar.gz: qddb-1.42.2/Headers/Qddb_ReducedAttr.h <==
/* Qddb/Headers/Qddb_ReducedAttr.h 
 * General schema definitions.
 *
 * Copyright (C) 1993, 1994 Herrin Software Development, Inc.
 * All rights reserved.
 *
 * This file is part of Qddb.
 *
 * Qddb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2
 * as published by the Free Software Foundation.
 *
 * Qddb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qddb; see the file LICENSE.  If not, write to:
 *
 *	Herrin Software Development, Inc. 
 *	R&D Division
 *	41 South Highland Ave. 
 *	Prestonsburg, KY 41653 
 */

#if !defined(_QDDB_REDUCEDATTR_H_)
#define _QDDB_REDUCEDATTR_H_

void Qddb_InitReducedAttrTable _ANSI_ARGS_((Schema *));
int Qddb_AddToReducedAttrTable _ANSI_ARGS_((Schema *, char *));
ReducedAttrTable *Qddb_GetReducedAttrTable _ANSI_ARGS_((Schema *));
ReducedAttrTable *Qddb_ReadReducedAttrTable _ANSI_ARGS_((Schema *));
int Qddb_WriteReducedAttrTable _ANSI_ARGS_((Schema *));
char *Qddb_IndexToReducedAttr _ANSI_ARGS_((int));
int Qddb_ReducedAttrToIndex _ANSI_ARGS_((char *));
void Qddb_FreeReducedAttrTable _ANSI_ARGS_(());
void Qddb_ReducedAttrToFullAttr _ANSI_ARGS_((Schema *, Entry));
void Qddb_FullAttrToReducedAttr _ANSI_ARGS_((Schema *, Entry));

#endif

==> qddb-1.43.tar.gz: qddb-1.43/Headers/Qddb_ReducedAttr.h <==
/* Qddb/Headers/Qddb_ReducedAttr.h 
 * General schema definitions.
 *
 * Copyright (C) 1993, 1994 Herrin Software Development, Inc.
 * All rights reserved.
 *
 * This file is part of Qddb.
 *
 * Qddb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2
 * as published by the Free Software Foundation.
 *
 * Qddb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qddb; see the file LICENSE.  If not, write to:
 *
 *	Herrin Software Development, Inc. 
 *	R&D Division
 *	41 South Highland Ave. 
 *	Prestonsburg, KY 41653 
 */

#if !defined(_QDDB_REDUCEDATTR_H_)
#define _QDDB_REDUCEDATTR_H_

void Qddb_InitReducedAttrTable _ANSI_ARGS_((Schema *));
char *Qddb_AddToReducedAttrTable _ANSI_ARGS_((Schema *, char *));
ReducedAttrTable *Qddb_GetReducedAttrTable _ANSI_ARGS_((Schema *));
ReducedAttrTable *Qddb_ReadReducedAttrTable _ANSI_ARGS_((Schema *));
int Qddb_WriteReducedAttrTable _ANSI_ARGS_((Schema *));
char *Qddb_IndexToReducedAttr _ANSI_ARGS_((int));
int Qddb_ReducedAttrToIndex _ANSI_ARGS_((char *));
void Qddb_FreeReducedAttrTable _ANSI_ARGS_(());
void Qddb_ReducedAttrToFullAttr _ANSI_ARGS_((Schema *, Entry));
void Qddb_FullAttrToReducedAttr _ANSI_ARGS_((Schema *, Entry));

#endif
